slepc-3.18.0 2022-10-01
Report Typos and Errors

# MFNSetFN

Specifies the function to be computed.

### Synopsis

    #include "slepcmfn.h"
    PetscErrorCode MFNSetFN(MFN mfn,FN fn)

Collective on mfn

### Input Parameters

| mfn | - matrix function context obtained from MFNCreate()
| fn | - the math function object

### Note

Use MFNGetFN() to retrieve the math function context (for example, to free it at the end of the computations).

### See Also

MFNGetFN()

### Level

beginner

### Location

src/mfn/interface/mfnbasic.c
Index of all MFN routines
Table of Contents for all manual pages
Index of all manual pages